package
module
Version:
v0.0.0-...-acad750
Opens a new window with list of versions in this module.
Published: Mar 27, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
goroutine-pool
goroutine-pool
Documentation
¶
type GoroutinePool struct {
Num int
}
GoroutinePool 协程池对象
type Task interface {
Running()
}
Task 定义任务接口
Source Files
¶
Click to show internal directories.
Click to hide internal directories.